import { createRouter, onBeforeRouteLeave } from 'vue-router'
import * as vueRouter from 'vue-router'
import Layout from '../layout/index.vue'
import navStore from '../store/nav.js'

// 路由信息
const routes = [
  /**
   * page 路由
   */
  {
    path: '/error',
    name: '404',
    component: Layout,
    children: [
      {
        path: '404',
        name: '404',
        component: () => import('../page/404.vue')
      }
    ]
  },
  /**
   * view 页面路由
   */
  {
    path: '/',
    name: '首页',
    component: Layout,
    children: [
      {
        path: '/',
        name: '首页',
        component: () => import('../views/home/index.vue')
      },
      {
        path: 'setting',
        name: '设置',
        component: () => import('../views/setting/index.vue')
      }
    ]
  },
  {
    path: '/user',
    name: '个人中心',
    component: Layout,
    children: [
      {
        path: 'index',
        name: '个人中心',
        component: () => import('../views/user/index.vue')
      },
      {
        path: 'pass',
        name: '修改密码',
        component: () => import('../views/user/pass.vue')
      }
    ]
  },
  {
    path: '/system',
    name: '系统设置',
    component: Layout,
    children: [
      {
        path: 'index',
        name: '系统设置',
        component: () => import('../views/system/index.vue')
      }
    ]
  }
]

// 导出路由
const router = createRouter({
  history: vueRouter.createWebHistory(),
  routes
})

router.beforeEach((to, from, next) => {
  const nav = navStore()
  nav.updateMenu(to)
  if (to.matched.length) {
    next()
  } else {
    next('/error/404')
    console.log(to)
  }
})

export default router
